@@ -69,9 +69,11 @@ A {text-decoration: none}
 </a><li type="square"><a href="fine-print.php?path=./2_System/46_multicast_not_working.faq#46_multicast_not_working.faq">When I use Clonezilla server edition to do a multicast clone, the client machines just stay in "Please Wait...", any hint ?
 </a><li type="square"><a href="fine-print.php?path=./2_System/47_translation.faq#47_translation.faq">I'd like to translate Clonezilla to other language, how can I help ? 
 </a><li type="square"><a href="fine-print.php?path=./2_System/48_drbl_client_active_directory.faq#48_drbl_client_active_directory.faq">How can I config my DRBL clients to use Active Directory authentication ?
-</a></dl></td><tr><br></table>
-<hr>
-Last modified: Wed Oct 8 21:47:22 CST 2008</CENTER>
+</a></dl></td><tr><br></table><hr><small>Last modified: Mon Oct 13 15:06:45 CST 2008</small><p><center><small>
+<a href="http://free.nchc.org.tw">NCHC Free Software Lab</a>. All Rights Reserved.
+Anyone is permitted to copy and distribute verbatim copies of this document under the terms of the <a href="http://www.gnu.org/licenses/fdl.html">GNU FDL</a> Free Documentation License.
+</center></small>
+</CENTER>
 <hr>
 <script type="text/javascript"><!--
 google_ad_client = "pub-9507710613356481";
